"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (twins)
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import iotics.api.common_pb2
import iotics.api.feed_pb2
import iotics.api.input_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListAllTwinsRequest(google.protobuf.message.Message):
    """List all twins."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADERS_FIELD_NUMBER: builtins.int
    RANGE_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def range(self) -> iotics.api.common_pb2.Range:
        """Listing result range"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        range: iotics.api.common_pb2.Range | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "range", b"range"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "range", b"range"]) -> None: ...

global___ListAllTwinsRequest = ListAllTwinsRequest

@typing.final
class ListAllTwinsResponse(google.protobuf.message.Message):
    """Response of the list all twins request.
    Note this is useful for sync responses. In case there are too many twins (millions)
    this request may fail. Better opt for async behaviour via stomp/websocket.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class TwinDetails(google.protobuf.message.Message):
        """ListAllTwinsResponse twin details."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        LOCATION_FIELD_NUMBER: builtins.int
        PROPERTIES_FIELD_NUMBER: builtins.int
        UPDATEDAT_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Twin identifier."""

        @property
        def location(self) -> iotics.api.common_pb2.GeoLocation:
            """Twin location (if set)."""

        @property
        def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]:
            """Twin custom properties."""

        @property
        def updatedAt(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """Twin updatedAt timestamp."""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
            location: iotics.api.common_pb2.GeoLocation | None = ...,
            properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
            updatedAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["location", b"location", "twinId", b"twinId", "updatedAt", b"updatedAt"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["location", b"location", "properties", b"properties", "twinId", b"twinId", "updatedAt", b"updatedAt"]) -> None: ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        """Payload of listed twins."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINS_FIELD_NUMBER: builtins.int
        @property
        def twins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListAllTwinsResponse.TwinDetails]: ...
        def __init__(
            self,
            *,
            twins: collections.abc.Iterable[global___ListAllTwinsResponse.TwinDetails] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["twins", b"twins"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def payload(self) -> global___ListAllTwinsResponse.Payload: ...
    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___ListAllTwinsResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___ListAllTwinsResponse = ListAllTwinsResponse

@typing.final
class CreateTwinRequest(google.protobuf.message.Message):
    """CreateTwinRequest is made to create a twin (idempotent)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """Arguments identifies the twin to create."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        id: builtins.str
        """Twin identifier string representation (simple string)"""
        def __init__(
            self,
            *,
            id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """Common headers"""

    @property
    def payload(self) -> global___CreateTwinRequest.Payload:
        """Request-specific payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___CreateTwinRequest.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___CreateTwinRequest = CreateTwinRequest

@typing.final
class CreateTwinResponse(google.protobuf.message.Message):
    """CreateTwinResponse is received when a twin has been created."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """Payload identifies the twin which was created."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Unique ID of the twin to delete"""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["twinId", b"twinId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["twinId", b"twinId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """Common headers"""

    @property
    def payload(self) -> global___CreateTwinResponse.Payload:
        """Request-specific payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___CreateTwinResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___CreateTwinResponse = CreateTwinResponse

@typing.final
class DeleteTwinRequest(google.protobuf.message.Message):
    """---------------------------------------

    DeleteRequest is made to delete a particular twin.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """Arguments identifies the twin to delete."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Unique ID of the twin to delete"""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["twinId", b"twinId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["twinId", b"twinId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """Common headers"""

    @property
    def args(self) -> global___DeleteTwinRequest.Arguments:
        """Request-specific arguments"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___DeleteTwinRequest.Arguments | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> None: ...

global___DeleteTwinRequest = DeleteTwinRequest

@typing.final
class DeleteTwinResponse(google.protobuf.message.Message):
    """Deleted is received when a twin has been deleted."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """Payload identifies the twin which was deleted."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Unique ID of the twin to delete"""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["twinId", b"twinId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["twinId", b"twinId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """Common headers"""

    @property
    def payload(self) -> global___DeleteTwinResponse.Payload:
        """Request-specific response"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___DeleteTwinResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___DeleteTwinResponse = DeleteTwinResponse

@typing.final
class DescribeTwinRequest(google.protobuf.message.Message):
    """Description of twin: Provides public metadata lookup for individual resources."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """Only one action argument is necessary."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Unique ID of the twin to describe"""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["twinId", b"twinId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["twinId", b"twinId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def args(self) -> global___DescribeTwinRequest.Arguments: ...
    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___DescribeTwinRequest.Arguments | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> None: ...

global___DescribeTwinRequest = DescribeTwinRequest

@typing.final
class FeedMeta(google.protobuf.message.Message):
    """Metadata message for this Feed."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEEDID_FIELD_NUMBER: builtins.int
    STORELAST_FIELD_NUMBER: builtins.int
    storeLast: builtins.bool
    @property
    def feedId(self) -> iotics.api.feed_pb2.FeedID: ...
    def __init__(
        self,
        *,
        feedId: iotics.api.feed_pb2.FeedID | None = ...,
        storeLast: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["feedId", b"feedId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["feedId", b"feedId", "storeLast", b"storeLast"]) -> None: ...

global___FeedMeta = FeedMeta

@typing.final
class InputMeta(google.protobuf.message.Message):
    """Metadata message for this input."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUTID_FIELD_NUMBER: builtins.int
    @property
    def inputId(self) -> iotics.api.input_pb2.InputID: ...
    def __init__(
        self,
        *,
        inputId: iotics.api.input_pb2.InputID | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["inputId", b"inputId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["inputId", b"inputId"]) -> None: ...

global___InputMeta = InputMeta

@typing.final
class DescribeTwinResponse(google.protobuf.message.Message):
    """The response for a description request on this twin."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class MetaResult(google.protobuf.message.Message):
        """Metadata result data bag for this feed."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOCATION_FIELD_NUMBER: builtins.int
        FEEDS_FIELD_NUMBER: builtins.int
        INPUTS_FIELD_NUMBER: builtins.int
        PROPERTIES_FIELD_NUMBER: builtins.int
        UPDATEDAT_FIELD_NUMBER: builtins.int
        @property
        def location(self) -> iotics.api.common_pb2.GeoLocation: ...
        @property
        def feeds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeedMeta]: ...
        @property
        def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InputMeta]: ...
        @property
        def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]:
            """Custom properties associated with this twin."""

        @property
        def updatedAt(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """Twin updatedAt timestamp."""

        def __init__(
            self,
            *,
            location: iotics.api.common_pb2.GeoLocation | None = ...,
            feeds: collections.abc.Iterable[global___FeedMeta] | None = ...,
            inputs: collections.abc.Iterable[global___InputMeta] | None = ...,
            properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
            updatedAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["location", b"location", "updatedAt", b"updatedAt"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feeds", b"feeds", "inputs", b"inputs", "location", b"location", "properties", b"properties", "updatedAt", b"updatedAt"]) -> None: ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        """Payload of described twins."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        RESULT_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """the twin"""

        @property
        def result(self) -> global___DescribeTwinResponse.MetaResult:
            """the description details"""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
            result: global___DescribeTwinResponse.MetaResult | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["result", b"result", "twinId", b"twinId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["result", b"result", "twinId", b"twinId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def payload(self) -> global___DescribeTwinResponse.Payload: ...
    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___DescribeTwinResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___DescribeTwinResponse = DescribeTwinResponse

@typing.final
class GeoLocationUpdate(google.protobuf.message.Message):
    """---------------------------------------

    GeoLocationUpdate describes the update of a twin location.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATION_FIELD_NUMBER: builtins.int
    @property
    def location(self) -> iotics.api.common_pb2.GeoLocation:
        """New location of the twin. If unset, the previously set location will be removed"""

    def __init__(
        self,
        *,
        location: iotics.api.common_pb2.GeoLocation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["location", b"location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["location", b"location"]) -> None: ...

global___GeoLocationUpdate = GeoLocationUpdate

@typing.final
class UpdateTwinRequest(google.protobuf.message.Message):
    """UpdateTwinRequest is used to update attributes (including metadata) of a given twin."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """UpdateTwinRequest mandatory arguments."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Unique ID of the twin to update"""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["twinId", b"twinId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["twinId", b"twinId"]) -> None: ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        """UpdateTwinRequest payload. One or more fields can be provided, depending on what needs to be updated.
        Note that the specified metadata changes are applied in the following order:
        tags, properties, labels, comments, location
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PROPERTIES_FIELD_NUMBER: builtins.int
        LOCATION_FIELD_NUMBER: builtins.int
        @property
        def properties(self) -> iotics.api.common_pb2.PropertyUpdate:
            """Custom properties to add/remove. Internal properties (such as location) cannot be modified here."""

        @property
        def location(self) -> global___GeoLocationUpdate:
            """Location to be set/unset"""

        def __init__(
            self,
            *,
            properties: iotics.api.common_pb2.PropertyUpdate | None = ...,
            location: global___GeoLocationUpdate | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["location", b"location", "properties", b"properties"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["location", b"location", "properties", b"properties"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """UpdateTwinRequest headers"""

    @property
    def args(self) -> global___UpdateTwinRequest.Arguments:
        """UpdateTwinRequest arguments"""

    @property
    def payload(self) -> global___UpdateTwinRequest.Payload:
        """UpdateTwinRequest payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___UpdateTwinRequest.Arguments | None = ...,
        payload: global___UpdateTwinRequest.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "payload", b"payload"]) -> None: ...

global___UpdateTwinRequest = UpdateTwinRequest

@typing.final
class UpdateTwinResponse(google.protobuf.message.Message):
    """UpdateTwinResponse describes an updated twin. It is received when the update operation is successful."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """UpdateTwinResponse payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Unique ID of the twin to delete"""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["twinId", b"twinId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["twinId", b"twinId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """UpdateTwinResponse headers"""

    @property
    def payload(self) -> global___UpdateTwinResponse.Payload:
        """UpdateTwinResponse payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___UpdateTwinResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___UpdateTwinResponse = UpdateTwinResponse

@typing.final
class UpsertTwinRequest(google.protobuf.message.Message):
    """UpsertTwinRequest describes the full state of a twin + its feeds and inputs to create or update (full update)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """UpsertTwinRequest payload. This state will be applied to the twin, feeds and inputs"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        PROPERTIES_FIELD_NUMBER: builtins.int
        LOCATION_FIELD_NUMBER: builtins.int
        FEEDS_FIELD_NUMBER: builtins.int
        INPUTS_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Unique ID of the twin to create/update"""

        @property
        def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]:
            """Twin Properties to set"""

        @property
        def location(self) -> iotics.api.common_pb2.GeoLocation:
            """Twin location to set. If not set the Twin will have no location"""

        @property
        def feeds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.feed_pb2.UpsertFeedWithMeta]:
            """Feeds with metadata to set for the twin"""

        @property
        def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.input_pb2.UpsertInputWithMeta]:
            """Inputs with metadata to set for the twin"""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
            properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
            location: iotics.api.common_pb2.GeoLocation | None = ...,
            feeds: collections.abc.Iterable[iotics.api.feed_pb2.UpsertFeedWithMeta] | None = ...,
            inputs: collections.abc.Iterable[iotics.api.input_pb2.UpsertInputWithMeta] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["location", b"location", "twinId", b"twinId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feeds", b"feeds", "inputs", b"inputs", "location", b"location", "properties", b"properties", "twinId", b"twinId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """UpdateTwinRequest headers"""

    @property
    def payload(self) -> global___UpsertTwinRequest.Payload:
        """UpdateTwinRequest payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___UpsertTwinRequest.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___UpsertTwinRequest = UpsertTwinRequest

@typing.final
class UpsertTwinResponse(google.protobuf.message.Message):
    """UpsertTwinResponse is received when a twin and its feeds and inputs have been created/updated."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """Payload identifies the twin which was created."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Unique ID of the created/updated twin"""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["twinId", b"twinId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["twinId", b"twinId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """Common headers"""

    @property
    def payload(self) -> global___UpsertTwinResponse.Payload:
        """Request-specific payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___UpsertTwinResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___UpsertTwinResponse = UpsertTwinResponse



# Copyright © 2022 IOTIC LABS LTD. info@iotics.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://github.com/Iotic-Labs/iotics-grpc-client-py/blob/main/LICENSE
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import typing

import grpc
import grpc._channel
from google.protobuf.wrappers_pb2 import StringValue

from iotics.api import common_pb2
from iotics.api import search_pb2
from iotics.api import search_pb2_grpc
from iotics.lib.grpc.helpers import create_headers, PER_PAGE_LIMIT
from iotics.lib.grpc.base import ApiBase

class SearchApi(ApiBase):
    stub_class = search_pb2_grpc.SearchAPIStub
    stub: search_pb2_grpc.SearchAPIStub

    @staticmethod
    def get_search_payload(
        text: typing.Optional[str] = None,
        location: typing.Optional[typing.Tuple[float, float, float]] = None,
        properties: typing.Optional[list] = None,
        response_type: search_pb2.ResponseType = search_pb2.ResponseType.MINIMAL
    ) -> search_pb2.SearchRequest.Payload:
        """Provides a correctly instantiated search request payload.

        Args:
            text: Filter results by text.
            location: Filter results for given geographic coordinates and radius.
            properties: Filter results for given metadata properties.
            response_type: Used for results in search responses.

        Returns: Payload object.
        """
        text = text and StringValue(value=text)
        location = location and common_pb2.GeoCircle(
            location=common_pb2.GeoLocation(lat=location[0], lon=location[1]),
            radiusKm=location[2]
        )
        payload = search_pb2.SearchRequest.Payload(
            responseType=response_type,
            filter=search_pb2.SearchRequest.Payload.Filter(text=text, location=location, properties=properties),
        )
        return payload

    def search_iter(
        self,
        client_app_id: str,
        payload: search_pb2.SearchRequest.Payload,
        scope: common_pb2.Scope = common_pb2.Scope.LOCAL,
        lang: typing.Optional[str] = None,
        timeout=3,
    ) -> typing.Iterator[search_pb2.SearchResponse]:
        """Searches IOTICSpace using an iterator.

        Args:
            client_app_id: Used to bind together and identify search requests and responses.
            payload: Contains filters, used to narrow results.
            scope: Used to filter search responses either to local IOTICSpace only or all visible IOTICSpaces.
            lang: The language to conduct text searches in
            timeout: Time after which the search iterator will stop blocking and listening for more replies.

        Returns: Search responses with results.
        """
        response_listener = self.get_response_listener(client_app_id, timeout=timeout)
        self.dispatch_request(client_app_id, payload, scope, lang)
        last_requested_page = 0
        try:
            for response in response_listener:
                current_page = int(response.headers.clientRef.split('_page')[1])
                if len(response.payload.twins) >= PER_PAGE_LIMIT and current_page >= last_requested_page:
                    last_requested_page += 1
                    self.dispatch_request(client_app_id, payload, scope, lang, page=current_page + 1)
                # Do not yield redundant responses if paginated search is called with global scope.
                if response.payload.twins or current_page == 0:
                    yield response
        except grpc._channel._MultiThreadedRendezvous as err:
            if err.code() != grpc.StatusCode.DEADLINE_EXCEEDED:
                raise

    def get_response_listener(self, client_app_id: str, timeout: int):
        """Initialises an iterator that listens for search request replies.

        Note: This function must be called before `dispatch_request` otherwise search responses may be lost.

        Args:
            client: Used to open a stream to receive search replies from IOTICSpace.
            client_app_id: A value that must match with the search request dispatched value.
            timeout: Time after which blocking operations on the response listener will be cancelled.

        Returns: Search results iterator with extra blocking (e.g. `time_remaining`) and non-blocking (e.g. `code`)
        methods.
        """
        sub_headers = common_pb2.SubscriptionHeaders(clientAppId=client_app_id, transactionRef=[client_app_id])
        # Define type here to avoid: `TypeError: 'ABCMeta' object is not subscriptable`.
        search_responses: grpc._channel._MultiThreadedRendezvous[search_pb2.SearchResponse] = \
            self.stub.ReceiveAllSearchResponses(sub_headers, timeout=timeout)
        return search_responses

    def dispatch_request(
        self,
        client_app_id: str,
        payload: search_pb2.SearchRequest.Payload,
        scope: common_pb2.Scope = common_pb2.Scope.LOCAL,
        lang: typing.Optional[str] = None,
        page: int = 0
    ) -> None:
        """Sends a (paginated) search request.

        Note: This function must be called after `get_response_listener` otherwise search responses may be lost.

        Args:
            client_app_id: A value used to identify replies for given search.
            payload: Contains filters, used to narrow results.
            scope: Used to filter search responses either to local IOTICSpace only or all visible IOTICSpaces.
            lang: The language to conduct text searches in
            page: Used to request offsetted results, as responses contain only up to `PER_PAGE_LIMIT` results per a
            request.
        """
        client_ref = f'{client_app_id}_page{page}'
        headers = create_headers(client_ref=client_ref, client_app_id=client_app_id)
        result_range = common_pb2.Range(
            limit=common_pb2.Limit(value=PER_PAGE_LIMIT),
            offset=common_pb2.Offset(value=PER_PAGE_LIMIT * page)
        )
        if lang:
            lang = StringValue(value=lang)
        request = search_pb2.SearchRequest(headers=headers, scope=scope, lang=lang, payload=payload, range=result_range)
        self.stub.DispatchSearchRequest(request)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (search)
"""

import abc
import collections.abc
import grpc
import grpc.aio
import iotics.api.common_pb2
import iotics.api.search_pb2
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SearchAPIStub:
    """---------------------------------------------------------------------------------------------------------------------

    SearchAPI provides a set of services to run synchronous and asynchronous search.
    Services only affect local resources, unless stated otherwise.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    DispatchSearchRequest: grpc.UnaryUnaryMultiCallable[
        iotics.api.search_pb2.SearchRequest,
        iotics.api.search_pb2.DispatchSearchResponse,
    ]
    """Send a search request. Results are expected asynchronously. (local and remote)"""

    SynchronousSearch: grpc.UnaryStreamMultiCallable[
        iotics.api.search_pb2.SearchRequest,
        iotics.api.search_pb2.SearchResponse,
    ]
    """Run a synchronous search based on a user timeout. (local and remote)"""

    ReceiveAllSearchResponses: grpc.UnaryStreamMultiCallable[
        iotics.api.common_pb2.SubscriptionHeaders,
        iotics.api.search_pb2.SearchResponse,
    ]
    """Receive all search responses associated to a set of Search request for a given client application ID."""

    AdvancedSearch: grpc.UnaryStreamMultiCallable[
        iotics.api.search_pb2.AdvancedSearchRequest,
        iotics.api.search_pb2.SearchResponse,
    ]
    """Run an advanced (filter) search request on a user timeout and return formatted results."""

class SearchAPIAsyncStub:
    """---------------------------------------------------------------------------------------------------------------------

    SearchAPI provides a set of services to run synchronous and asynchronous search.
    Services only affect local resources, unless stated otherwise.
    """

    DispatchSearchRequest: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.search_pb2.SearchRequest,
        iotics.api.search_pb2.DispatchSearchResponse,
    ]
    """Send a search request. Results are expected asynchronously. (local and remote)"""

    SynchronousSearch: grpc.aio.UnaryStreamMultiCallable[
        iotics.api.search_pb2.SearchRequest,
        iotics.api.search_pb2.SearchResponse,
    ]
    """Run a synchronous search based on a user timeout. (local and remote)"""

    ReceiveAllSearchResponses: grpc.aio.UnaryStreamMultiCallable[
        iotics.api.common_pb2.SubscriptionHeaders,
        iotics.api.search_pb2.SearchResponse,
    ]
    """Receive all search responses associated to a set of Search request for a given client application ID."""

    AdvancedSearch: grpc.aio.UnaryStreamMultiCallable[
        iotics.api.search_pb2.AdvancedSearchRequest,
        iotics.api.search_pb2.SearchResponse,
    ]
    """Run an advanced (filter) search request on a user timeout and return formatted results."""

class SearchAPIServicer(metaclass=abc.ABCMeta):
    """---------------------------------------------------------------------------------------------------------------------

    SearchAPI provides a set of services to run synchronous and asynchronous search.
    Services only affect local resources, unless stated otherwise.
    """

    @abc.abstractmethod
    def DispatchSearchRequest(
        self,
        request: iotics.api.search_pb2.SearchRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.search_pb2.DispatchSearchResponse, collections.abc.Awaitable[iotics.api.search_pb2.DispatchSearchResponse]]:
        """Send a search request. Results are expected asynchronously. (local and remote)"""

    @abc.abstractmethod
    def SynchronousSearch(
        self,
        request: iotics.api.search_pb2.SearchRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[iotics.api.search_pb2.SearchResponse], collections.abc.AsyncIterator[iotics.api.search_pb2.SearchResponse]]:
        """Run a synchronous search based on a user timeout. (local and remote)"""

    @abc.abstractmethod
    def ReceiveAllSearchResponses(
        self,
        request: iotics.api.common_pb2.SubscriptionHeaders,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[iotics.api.search_pb2.SearchResponse], collections.abc.AsyncIterator[iotics.api.search_pb2.SearchResponse]]:
        """Receive all search responses associated to a set of Search request for a given client application ID."""

    @abc.abstractmethod
    def AdvancedSearch(
        self,
        request: iotics.api.search_pb2.AdvancedSearchRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[iotics.api.search_pb2.SearchResponse], collections.abc.AsyncIterator[iotics.api.search_pb2.SearchResponse]]:
        """Run an advanced (filter) search request on a user timeout and return formatted results."""

def add_SearchAPIServicer_to_server(servicer: SearchAPIServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Copyright © 2022 IOTIC LABS LTD. info@iotics.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://github.com/Iotic-Labs/iotics-grpc-client-py/blob/main/LICENSE
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import json
import typing

import grpc
import grpc._channel
from google.protobuf.wrappers_pb2 import BoolValue

from iotics.api import common_pb2
from iotics.api import feed_pb2
from iotics.api import input_pb2
from iotics.api import interest_pb2
from iotics.api import interest_pb2_grpc
from iotics.api.common_pb2 import TwinID
from iotics.api.feed_pb2 import FeedID
from iotics.api.input_pb2 import InputID
from iotics.api.interest_pb2 import Interest
from .base import ApiBase
from .helpers import create_headers, create_timestamp


class InterestApi(ApiBase):
    stub_class = interest_pb2_grpc.InterestAPIStub
    stub: interest_pb2_grpc.InterestAPIStub

    @staticmethod
    def _build_interest(follower_twin_did, followed_twin_did, followed_feed_id, remote_host_id=None):
        return interest_pb2.Interest(
            followerTwinId=common_pb2.TwinID(value=follower_twin_did),
            followedFeed=interest_pb2.Interest.FollowedFeed(
                feed=feed_pb2.Feed(
                    id=common_pb2.FeedID(value=followed_feed_id),
                    twinId=common_pb2.TwinID(value=followed_twin_did)
                ),
                hostId=common_pb2.HostID(value=remote_host_id) if remote_host_id else None
            )
        )

    def fetch_interests(
            self,
            follower_twin_did: str,
            followed_twin_did: str,
            followed_feed_id: str,
            remote_host_id: typing.Optional[str] = None,
            fetch_last_stored: bool = True,
            headers: typing.Optional[common_pb2.Headers] = None
    ) -> interest_pb2.FetchInterestResponse:
        """Receive streaming data as it is shared to a feed

        Args:
            follower_twin_did: Decentralized identifier of the twin seeking data
            followed_twin_did: Decentralized identifier of the twin providing data
            followed_feed_id: Identifier (unique per-twin) of the feed providing data
            remote_host_id: Remote host on which the followed twin is found (None if local)
            fetch_last_stored: Whether to return the data most recently shared to the feed immediately, rather than
                waiting for a new feed share to return any data
            headers: optional request headers

        Returns: Iterator of Response objects, streamed as data is shared to the feed, with an "interest" attribute
        recapitulating the submitted parameters, and a "feedData" attribute with the following attributes:
            occurredAt: Timestamp for the shared data, expressed in seconds since the epoch
            mime: MIME type of the shared data
            data: The data shared to the feed
        """
        req = interest_pb2.FetchInterestRequest(
            headers=headers or create_headers(),
            args=interest_pb2.FetchInterestRequest.Arguments(
                interest=Interest(followerTwinId=TwinID(id=follower_twin_did), followedFeedId=FeedID(
                    id=followed_feed_id, twinId=followed_twin_did, hostId=remote_host_id))
            ),
            fetchLastStored=BoolValue(value=fetch_last_stored)
        )
        # Define type here to avoid: `TypeError: 'ABCMeta' object is not subscriptable`.
        interests: grpc._channel._MultiThreadedRendezvous[interest_pb2.FetchInterestResponse] = \
            self.stub.FetchInterests(req)
        return interests

    def fetch_last_stored(
            self,
            follower_twin_did: str,
            followed_twin_did: str,
            followed_feed_id: str,
            remote_host_id: typing.Optional[str] = None,
            headers: typing.Optional[common_pb2.Headers] = None
    ) -> interest_pb2.FetchInterestResponse:
        """Retrieve the data most recently shared to a given feed

        Args:
            follower_twin_did: Decentralized identifier of the twin seeking data
            followed_twin_did: Decentralized identifier of the twin providing data
            followed_feed_id: Identifier (unique per-twin) of the feed providing data
            remote_host_id: Remote host on which the followed twin is found (None if local)
            headers: optional request headers

        Returns: Response object with an "interest" attribute recapitulating the submitted parameters, and a "feedData"
        attribute with the following attributes:
            occurredAt: Timestamp for the shared data, expressed in seconds since the epoch
            mime: MIME type of the shared data
            data: The data shared to the feed
        """
        req = interest_pb2.FetchLastStoredRequest(
            headers=headers or create_headers(),
            args=interest_pb2.FetchLastStoredRequest.Arguments(
                interest=Interest(followerTwinId=TwinID(id=follower_twin_did), followedFeedId=FeedID(
                    id=followed_feed_id, twinId=followed_twin_did, hostId=remote_host_id))
            )
        )
        return self.stub.FetchLastStored(req)

    def send_input_message(
        self,
        message: typing.Any,
        sender_twin_did: str,
        receiver_twin_did: str,
        input_id: str,
        mime_type: str = 'application/json',
        remote_host_id: typing.Optional[str] = None,
        headers: typing.Optional[common_pb2.Headers] = None,
    ) -> interest_pb2.SendInputMessageResponse:
        """Sends a message to the input of a local or remote twin.

        Args:
            message: What to send the remote twin, usually in the form of a dict with keys matching the input's Values
            sender_twin_did: The twin sending the message
            receiver_twin_did: The twin receiving the message
            input_id: The ID of the input where the message will be sent
            mime_type: The MIME type for the message
            remote_host_id: If the receiver twin is remote, its host ID (None if local)
            headers: optional request headers

        Returns: Response object indicating success

        """
        input_interest = interest_pb2.InputInterest(
            senderTwinId=common_pb2.TwinID(id=sender_twin_did),
            destInputId=InputID(id=input_id, twinId=receiver_twin_did, hostId=remote_host_id),
        )
        input_message = input_pb2.InputMessage(
            occurredAt=create_timestamp(),
            mime=mime_type,
            data=json.dumps(message).encode(),
        )
        request = interest_pb2.SendInputMessageRequest(
            headers=headers or create_headers(),
            args=interest_pb2.SendInputMessageRequest.Arguments(interest=input_interest),
            payload=interest_pb2.SendInputMessageRequest.Payload(message=input_message),
        )
        return self.stub.SendInputMessage(request=request)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (common)
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Scope:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ScopeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Scope.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GLOBAL: _Scope.ValueType  # 0
    LOCAL: _Scope.ValueType  # 1

class Scope(_Scope, metaclass=_ScopeEnumTypeWrapper):
    """Scope is a request parameter used to apply a scope to a given request.
    GLOBAL - go over the network/target the public Twin
    LOCAL - restrain the request to the local host
    """

GLOBAL: Scope.ValueType  # 0
LOCAL: Scope.ValueType  # 1
global___Scope = Scope

@typing.final
class Limit(google.protobuf.message.Message):
    """---------------------------------------------------------------------------------------------------------------------

    Limit is a request parameter to limit the number of results.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    """Max number of results (under configuration max limit constraint)"""
    def __init__(
        self,
        *,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___Limit = Limit

@typing.final
class Offset(google.protobuf.message.Message):
    """Offset is a request parameter applicable in conjunction with the "Limit"
    request parameter to start returning results from the given offset.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    """Result number to start from"""
    def __init__(
        self,
        *,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___Offset = Offset

@typing.final
class Range(google.protobuf.message.Message):
    """Range is the combination of the "Limit" and "Offset" is a request parameters. It is
    used to return a specific range of results. Default value is applied if no limit is specified.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIMIT_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    @property
    def limit(self) -> global___Limit: ...
    @property
    def offset(self) -> global___Offset: ...
    def __init__(
        self,
        *,
        limit: global___Limit | None = ...,
        offset: global___Offset | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["limit", b"limit", "offset", b"offset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["limit", b"limit", "offset", b"offset"]) -> None: ...

global___Range = Range

@typing.final
class LangLiteral(google.protobuf.message.Message):
    """LangLiteral is a metadata property type describing a string with a given language (implicit datatype: rdf:langString)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANG_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    lang: builtins.str
    """2-character language code"""
    value: builtins.str
    """String representation of the value"""
    def __init__(
        self,
        *,
        lang: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lang", b"lang", "value", b"value"]) -> None: ...

global___LangLiteral = LangLiteral

@typing.final
class StringLiteral(google.protobuf.message.Message):
    """StringLiteral is a metadata property type describing a string without a language (implicit datatype: rdf:string)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    """String representation of the value"""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___StringLiteral = StringLiteral

@typing.final
class Literal(google.protobuf.message.Message):
    """Literal is a metadata property type describing a literal with the given datatype (implicit datatype: rdfs:Literal)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATATYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    dataType: builtins.str
    """XSD data type (e.g. double) without its namespace prefix (http://www.w3.org/2001/XMLSchema#). The following types
    are currently supported:
    dateTime, time, date, boolean, integer, decimal, float, double, nonPositiveInteger, negativeInteger,
    nonNegativeInteger, positiveInteger, long, unsignedLong, int, unsignedInt, short, unsignedShort, byte,
    unsignedByte, base64Binary, anyURI
    """
    value: builtins.str
    """String representation of the value according to XSD datatype specification"""
    def __init__(
        self,
        *,
        dataType: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataType", b"dataType", "value", b"value"]) -> None: ...

global___Literal = Literal

@typing.final
class Uri(google.protobuf.message.Message):
    """Uri is a metadata property type describing a Uri."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    """String representation of the value"""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___Uri = Uri

@typing.final
class Property(google.protobuf.message.Message):
    """Property is a metadata property with a single value.
    Multiple instances are used to represent a key (predicate) with multiple values.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    LITERALVALUE_FIELD_NUMBER: builtins.int
    LANGLITERALVALUE_FIELD_NUMBER: builtins.int
    STRINGLITERALVALUE_FIELD_NUMBER: builtins.int
    URIVALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """The key (predicate) of the property"""
    @property
    def literalValue(self) -> global___Literal: ...
    @property
    def langLiteralValue(self) -> global___LangLiteral: ...
    @property
    def stringLiteralValue(self) -> global___StringLiteral: ...
    @property
    def uriValue(self) -> global___Uri: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        literalValue: global___Literal | None = ...,
        langLiteralValue: global___LangLiteral | None = ...,
        stringLiteralValue: global___StringLiteral | None = ...,
        uriValue: global___Uri | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["langLiteralValue", b"langLiteralValue", "literalValue", b"literalValue", "stringLiteralValue", b"stringLiteralValue", "uriValue", b"uriValue", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "langLiteralValue", b"langLiteralValue", "literalValue", b"literalValue", "stringLiteralValue", b"stringLiteralValue", "uriValue", b"uriValue", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["literalValue", "langLiteralValue", "stringLiteralValue", "uriValue"] | None: ...

global___Property = Property

@typing.final
class GeoLocation(google.protobuf.message.Message):
    """GeoLocation is the geographic location of a Twin."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAT_FIELD_NUMBER: builtins.int
    LON_FIELD_NUMBER: builtins.int
    lat: builtins.float
    """Latitude"""
    lon: builtins.float
    """Longitude"""
    def __init__(
        self,
        *,
        lat: builtins.float = ...,
        lon: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lat", b"lat", "lon", b"lon"]) -> None: ...

global___GeoLocation = GeoLocation

@typing.final
class GeoCircle(google.protobuf.message.Message):
    """GeoCircle is an approximate geographic location."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATION_FIELD_NUMBER: builtins.int
    RADIUSKM_FIELD_NUMBER: builtins.int
    radiusKm: builtins.float
    """Radius (Km) relative to the geolocation"""
    @property
    def location(self) -> global___GeoLocation: ...
    def __init__(
        self,
        *,
        location: global___GeoLocation | None = ...,
        radiusKm: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["location", b"location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["location", b"location", "radiusKm", b"radiusKm"]) -> None: ...

global___GeoCircle = GeoCircle

@typing.final
class RequestInfo(google.protobuf.message.Message):
    """RequestInfo is a request parameter used to provide additional information about the request.
    It will also be included in the response.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class TraceCtxEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    STARTTIME_FIELD_NUMBER: builtins.int
    TRACECTX_FIELD_NUMBER: builtins.int
    @property
    def startTime(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start timestamp of the request, from the perspective of the host (server). Values supplied by the client will be
        ignored
        """

    @property
    def traceCtx(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Headers for tracing support (W3C Trace Context / Baggage). If no valid context is provided by the client, the host
        (server) will initialise one.
        """

    def __init__(
        self,
        *,
        startTime: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        traceCtx: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["startTime", b"startTime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["startTime", b"startTime", "traceCtx", b"traceCtx"]) -> None: ...

global___RequestInfo = RequestInfo

@typing.final
class Headers(google.protobuf.message.Message):
    """Headers describes the common headers applicable to all the API requests
    (except for Search subscribe: see SubscriptionHeaders).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENTREF_FIELD_NUMBER: builtins.int
    CLIENTAPPID_FIELD_NUMBER: builtins.int
    TRANSACTIONREF_FIELD_NUMBER: builtins.int
    CONSUMERGROUP_FIELD_NUMBER: builtins.int
    REQUESTTIMEOUT_FIELD_NUMBER: builtins.int
    REQUESTINFO_FIELD_NUMBER: builtins.int
    clientRef: builtins.str
    """Optional client reference. Any responses associated with the request will include this reference."""
    clientAppId: builtins.str
    """User namespace used to group all the requests/responses"""
    @property
    def transactionRef(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Used to loosely link requests/responses in a distributed environment
        each layer can add its own id to the list. Transaction ref is limited to
        a max of 16 elements per list and, for each list item, a max length of 36
        characters
        """

    @property
    def consumerGroup(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Used for group listener, optional - Not implemented yet"""

    @property
    def requestTimeout(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Client request timeout used to stop the request processing once the timeout is reached"""

    @property
    def requestInfo(self) -> global___RequestInfo: ...
    def __init__(
        self,
        *,
        clientRef: builtins.str = ...,
        clientAppId: builtins.str = ...,
        transactionRef: collections.abc.Iterable[builtins.str] | None = ...,
        consumerGroup: google.protobuf.wrappers_pb2.StringValue | None = ...,
        requestTimeout: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        requestInfo: global___RequestInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["consumerGroup", b"consumerGroup", "requestInfo", b"requestInfo", "requestTimeout", b"requestTimeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clientAppId", b"clientAppId", "clientRef", b"clientRef", "consumerGroup", b"consumerGroup", "requestInfo", b"requestInfo", "requestTimeout", b"requestTimeout", "transactionRef", b"transactionRef"]) -> None: ...

global___Headers = Headers

@typing.final
class SubscriptionHeaders(google.protobuf.message.Message):
    """SubscriptionHeaders describes a Search subscribe header. (Will be DEPRECATED with the client-ref from Headers)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENTAPPID_FIELD_NUMBER: builtins.int
    TRANSACTIONREF_FIELD_NUMBER: builtins.int
    CONSUMERGROUP_FIELD_NUMBER: builtins.int
    clientAppId: builtins.str
    """User namespace used to group all the requests/responses"""
    @property
    def transactionRef(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Used to loosely link requests/responses in a distributed environment
        each layer can add its own id to the list. Transaction ref is limited to
        a max of 16 elements per list and, for each list item, a max length of 36
        characters
        """

    @property
    def consumerGroup(self) -> google.protobuf.wrappers_pb2.StringValue:
        """consumer group (for group listener, optional) - Not implemented yet"""

    def __init__(
        self,
        *,
        clientAppId: builtins.str = ...,
        transactionRef: collections.abc.Iterable[builtins.str] | None = ...,
        consumerGroup: google.protobuf.wrappers_pb2.StringValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["consumerGroup", b"consumerGroup"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clientAppId", b"clientAppId", "consumerGroup", b"consumerGroup", "transactionRef", b"transactionRef"]) -> None: ...

global___SubscriptionHeaders = SubscriptionHeaders

@typing.final
class TwinID(google.protobuf.message.Message):
    """TwinID is the virtual representation of a (physical, purely virtual or hybrid) device,
    is only ever located in the host it was created.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    HOSTID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Twin Identifier (using DID format)"""
    hostId: builtins.str
    """Host Identifier (using DID format)"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        hostId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hostId", b"hostId", "id", b"id"]) -> None: ...

global___TwinID = TwinID

@typing.final
class Value(google.protobuf.message.Message):
    """Value is the definition of an individual piece of data within a Feed share or an Input send. Values are purely descriptive, e.g. a
    follower should expect data to match the values associated with said Feed/Input but must be able to recover where this
    is not the case.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    DATATYPE_FIELD_NUMBER: builtins.int
    label: builtins.str
    """label is the unique identifier of the value. It is language-neutral. E.g.: "t" / "temp" / "temperature"."""
    comment: builtins.str
    """comment is the (optional) human-readable description of the value. It is language-specific. E.g.: "Engine oil temperature" """
    unit: builtins.str
    """unit is the (optional) fully qualified ontology string URI of the unit, e.g. http://purl.obolibrary.org/obo/UO_0000027"""
    dataType: builtins.str
    """dataType is the xsd type in shorthand notation.
    Currently supported types are: base64Binary, decimal, float, double, dateTime, time, date, boolean, integer,
    nonPositiveInteger, negativeInteger, nonNegativeInteger, positiveInteger, long, unsignedLong, int, unsignedInt,
    short, unsignedShort, byte, unsignedByte
    """
    def __init__(
        self,
        *,
        label: builtins.str = ...,
        comment: builtins.str = ...,
        unit: builtins.str = ...,
        dataType: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["comment", b"comment", "dataType", b"dataType", "label", b"label", "unit", b"unit"]) -> None: ...

global___Value = Value

@typing.final
class Values(google.protobuf.message.Message):
    """Values defines a set of values to be added and/or deleted."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDED_FIELD_NUMBER: builtins.int
    DELETEDBYLABEL_FIELD_NUMBER: builtins.int
    @property
    def added(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Value]:
        """added is the list of values to be added. Note that deletedByLabel takes precedence over this, i.e. if both added
        and deletedByLabel contain the same value, the value will be deleted.
        """

    @property
    def deletedByLabel(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """deletedByLabel is the list of labels of values to be deleted."""

    def __init__(
        self,
        *,
        added: collections.abc.Iterable[global___Value] | None = ...,
        deletedByLabel: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["added", b"added", "deletedByLabel", b"deletedByLabel"]) -> None: ...

global___Values = Values

@typing.final
class FeedData(google.protobuf.message.Message):
    """FeedData is set of datapoints shared via a Feed."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OCCURREDAT_FIELD_NUMBER: builtins.int
    MIME_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    mime: builtins.str
    """mime is the mime type of the encoded data."""
    data: builtins.bytes
    """data is the actual set of datapoints, encoded according the the mime type. The data should follow the Feed's
    value definitions but that is not enforced. (See also Value)
    """
    @property
    def occurredAt(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """occurredAt is the UTC timestamp of the sample. Typically this is either the time at which an application shared
        this sample or the time applicable to the sample itself (such as an hourly weather observation).
        (Optional: set to host time if not provided)
        """

    def __init__(
        self,
        *,
        occurredAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        mime: builtins.str = ...,
        data: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["occurredAt", b"occurredAt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "mime", b"mime", "occurredAt", b"occurredAt"]) -> None: ...

global___FeedData = FeedData

@typing.final
class PropertyUpdate(google.protobuf.message.Message):
    """PropertyUpdate describes the update of resource's underlying properties.
    Can be used to add, replace, or delete properties. The order of operations is:
    clearedAll (if True), deleted, deletedByKey, added.
    Note that internal properties (such as location) cannot be modified here.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLEAREDALL_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    DELETEDBYKEY_FIELD_NUMBER: builtins.int
    ADDED_FIELD_NUMBER: builtins.int
    clearedAll: builtins.bool
    """Delete all properties currently set on the resource."""
    @property
    def deleted(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Property]:
        """Delete specific exact properties (by key and value). This operation is ignored if clearAll is True."""

    @property
    def deletedByKey(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Delete any properties with the given keys (predicates). This operation is ignored if clearAll is True."""

    @property
    def added(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Property]:
        """Adds the given properties"""

    def __init__(
        self,
        *,
        clearedAll: builtins.bool = ...,
        deleted: collections.abc.Iterable[global___Property] | None = ...,
        deletedByKey: collections.abc.Iterable[builtins.str] | None = ...,
        added: collections.abc.Iterable[global___Property] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["added", b"added", "clearedAll", b"clearedAll", "deleted", b"deleted", "deletedByKey", b"deletedByKey"]) -> None: ...

global___PropertyUpdate = PropertyUpdate



# Copyright © 2022 IOTIC LABS LTD. info@iotics.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://github.com/Iotic-Labs/iotics-grpc-client-py/blob/main/LICENSE
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import typing
from iotics.api import common_pb2
from iotics.api import host_pb2
from iotics.api import host_pb2_grpc
from iotics.lib.grpc.base import ApiBase
from iotics.lib.grpc.helpers import create_headers


class HostApi(ApiBase):
    stub_class = host_pb2_grpc.HostAPIStub
    stub: host_pb2_grpc.HostAPIStub

    def get_local_host_id(self, headers: typing.Optional[common_pb2.Headers] = None) -> host_pb2.GetHostIDResponse:
        """ get the id of the local host
        """
        request = host_pb2.GetHostIDRequest(
            headers=headers or create_headers(),
        )

        resp = self.stub.GetHostID(request)

        return resp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/interest.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/interest.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from iotics.api import common_pb2 as iotics_dot_api_dot_common__pb2
from iotics.api import feed_pb2 as iotics_dot_api_dot_feed__pb2
from iotics.api import input_pb2 as iotics_dot_api_dot_input__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19iotics/api/interest.proto\x12\niotics.api\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17iotics/api/common.proto\x1a\x15iotics/api/feed.proto\x1a\x16iotics/api/input.proto\"~\n\rInputInterest\x12\x36\n\x0csenderTwinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x0csenderTwinId\x12\x35\n\x0b\x64\x65stInputId\x18\x02 \x01(\x0b\x32\x13.iotics.api.InputIDR\x0b\x64\x65stInputId\"\xd5\x02\n\x17SendInputMessageRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x41\n\x04\x61rgs\x18\x02 \x01(\x0b\x32-.iotics.api.SendInputMessageRequest.ArgumentsR\x04\x61rgs\x12\x45\n\x07payload\x18\x03 \x01(\x0b\x32+.iotics.api.SendInputMessageRequest.PayloadR\x07payload\x1a=\n\x07Payload\x12\x32\n\x07message\x18\x01 \x01(\x0b\x32\x18.iotics.api.InputMessageR\x07message\x1a\x42\n\tArguments\x12\x35\n\x08interest\x18\x01 \x01(\x0b\x32\x19.iotics.api.InputInterestR\x08interest\"I\n\x18SendInputMessageResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\"\x82\x01\n\x08Interest\x12:\n\x0e\x66ollowerTwinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x0e\x66ollowerTwinId\x12:\n\x0e\x66ollowedFeedId\x18\x02 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x0e\x66ollowedFeedId\"\x8a\x02\n\x14\x46\x65tchInterestRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12>\n\x04\x61rgs\x18\x02 \x01(\x0b\x32*.iotics.api.FetchInterestRequest.ArgumentsR\x04\x61rgs\x12\x44\n\x0f\x66\x65tchLastStored\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0f\x66\x65tchLastStored\x1a=\n\tArguments\x12\x30\n\x08interest\x18\x01 \x01(\x0b\x32\x14.iotics.api.InterestR\x08interest\"\xfa\x01\n\x15\x46\x65tchInterestResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x43\n\x07payload\x18\x02 \x01(\x0b\x32).iotics.api.FetchInterestResponse.PayloadR\x07payload\x1am\n\x07Payload\x12\x30\n\x08interest\x18\x01 \x01(\x0b\x32\x14.iotics.api.InterestR\x08interest\x12\x30\n\x08\x66\x65\x65\x64\x44\x61ta\x18\x02 \x01(\x0b\x32\x14.iotics.api.FeedDataR\x08\x66\x65\x65\x64\x44\x61ta\"\xc8\x01\n\x16\x46\x65tchLastStoredRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x04\x61rgs\x18\x02 \x01(\x0b\x32,.iotics.api.FetchLastStoredRequest.ArgumentsR\x04\x61rgs\x1a=\n\tArguments\x12\x30\n\x08interest\x18\x01 \x01(\x0b\x32\x14.iotics.api.InterestR\x08interest2\xa5\x02\n\x0bInterestAPI\x12Y\n\x0e\x46\x65tchInterests\x12 .iotics.api.FetchInterestRequest\x1a!.iotics.api.FetchInterestResponse\"\x00\x30\x01\x12Z\n\x0f\x46\x65tchLastStored\x12\".iotics.api.FetchLastStoredRequest\x1a!.iotics.api.FetchInterestResponse\"\x00\x12_\n\x10SendInputMessage\x12#.iotics.api.SendInputMessageRequest\x1a$.iotics.api.SendInputMessageResponse\"\x00\x42\x81\x01\n\x0e\x63om.iotics.apiB\rInterestProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.interest_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\rInterestProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_INPUTINTEREST']._serialized_start=145
  _globals['_INPUTINTEREST']._serialized_end=271
  _globals['_SENDINPUTMESSAGEREQUEST']._serialized_start=274
  _globals['_SENDINPUTMESSAGEREQUEST']._serialized_end=615
  _globals['_SENDINPUTMESSAGEREQUEST_PAYLOAD']._serialized_start=486
  _globals['_SENDINPUTMESSAGEREQUEST_PAYLOAD']._serialized_end=547
  _globals['_SENDINPUTMESSAGEREQUEST_ARGUMENTS']._serialized_start=549
  _globals['_SENDINPUTMESSAGEREQUEST_ARGUMENTS']._serialized_end=615
  _globals['_SENDINPUTMESSAGERESPONSE']._serialized_start=617
  _globals['_SENDINPUTMESSAGERESPONSE']._serialized_end=690
  _globals['_INTEREST']._serialized_start=693
  _globals['_INTEREST']._serialized_end=823
  _globals['_FETCHINTERESTREQUEST']._serialized_start=826
  _globals['_FETCHINTERESTREQUEST']._serialized_end=1092
  _globals['_FETCHINTERESTREQUEST_ARGUMENTS']._serialized_start=1031
  _globals['_FETCHINTERESTREQUEST_ARGUMENTS']._serialized_end=1092
  _globals['_FETCHINTERESTRESPONSE']._serialized_start=1095
  _globals['_FETCHINTERESTRESPONSE']._serialized_end=1345
  _globals['_FETCHINTERESTRESPONSE_PAYLOAD']._serialized_start=1236
  _globals['_FETCHINTERESTRESPONSE_PAYLOAD']._serialized_end=1345
  _globals['_FETCHLASTSTOREDREQUEST']._serialized_start=1348
  _globals['_FETCHLASTSTOREDREQUEST']._serialized_end=1548
  _globals['_FETCHLASTSTOREDREQUEST_ARGUMENTS']._serialized_start=1031
  _globals['_FETCHLASTSTOREDREQUEST_ARGUMENTS']._serialized_end=1092
  _globals['_INTERESTAPI']._serialized_start=1551
  _globals['_INTERESTAPI']._serialized_end=1844
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (search)
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import google.rpc.status_pb2
import iotics.api.common_pb2
import iotics.api.feed_pb2
import iotics.api.input_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ResponseType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ResponseTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ResponseType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FULL: _ResponseType.ValueType  # 0
    LOCATED: _ResponseType.ValueType  # 1
    MINIMAL: _ResponseType.ValueType  # 2

class ResponseType(_ResponseType, metaclass=_ResponseTypeEnumTypeWrapper):
    """ResponseType describes the type of the search response.
    - FULL - Returns full responses including twins, feeds and inputs identifiers, properties and location
    - LOCATED - Returns located responses including twins identifier, location and label (for the provided language or default)
    - MINIMAL - Returns minimal responses including twins identifier only
    """

FULL: ResponseType.ValueType  # 0
LOCATED: ResponseType.ValueType  # 1
MINIMAL: ResponseType.ValueType  # 2
global___ResponseType = ResponseType

@typing.final
class SearchRequest(google.protobuf.message.Message):
    """SearchRequest describes a search request used for both synchronous and asynchronous search."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """Search request payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Filter(google.protobuf.message.Message):
            """Search request filters, any of these can be used in combination or on their own."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            TEXT_FIELD_NUMBER: builtins.int
            LOCATION_FIELD_NUMBER: builtins.int
            PROPERTIES_FIELD_NUMBER: builtins.int
            @property
            def text(self) -> google.protobuf.wrappers_pb2.StringValue:
                """Text filtering. One or more keywords which must match text from twin properties. Note that any (rather than all)
                of the keywords will produce a match.
                """

            @property
            def location(self) -> iotics.api.common_pb2.GeoCircle:
                """Location filtering: area within which twins must be located"""

            @property
            def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]:
                """Properties filtering: one or more exact properties, all of which twins must have."""

            def __init__(
                self,
                *,
                text: google.protobuf.wrappers_pb2.StringValue | None = ...,
                location: iotics.api.common_pb2.GeoCircle | None = ...,
                properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["location", b"location", "text", b"text"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["location", b"location", "properties", b"properties", "text", b"text"]) -> None: ...

        RESPONSETYPE_FIELD_NUMBER: builtins.int
        EXPIRYTIMEOUT_FIELD_NUMBER: builtins.int
        FILTER_FIELD_NUMBER: builtins.int
        responseType: global___ResponseType.ValueType
        """Expected response type"""
        @property
        def expiryTimeout(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """UTC time (millis from epoch / unix time) when this search request has to be considered expired."""

        @property
        def filter(self) -> global___SearchRequest.Payload.Filter:
            """Search Request filters"""

        def __init__(
            self,
            *,
            responseType: global___ResponseType.ValueType = ...,
            expiryTimeout: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            filter: global___SearchRequest.Payload.Filter | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["expiryTimeout", b"expiryTimeout", "filter", b"filter"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["expiryTimeout", b"expiryTimeout", "filter", b"filter", "responseType", b"responseType"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    LANG_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    RANGE_FIELD_NUMBER: builtins.int
    scope: iotics.api.common_pb2.Scope.ValueType
    """Search request scope"""
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """Search request headers"""

    @property
    def lang(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Search request language, applicable to text filtering. If not specified, text search will match any language."""

    @property
    def payload(self) -> global___SearchRequest.Payload:
        """Search request payload"""

    @property
    def range(self) -> iotics.api.common_pb2.Range:
        """Search request range"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        scope: iotics.api.common_pb2.Scope.ValueType = ...,
        lang: google.protobuf.wrappers_pb2.StringValue | None = ...,
        payload: global___SearchRequest.Payload | None = ...,
        range: iotics.api.common_pb2.Range | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "lang", b"lang", "payload", b"payload", "range", b"range"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "lang", b"lang", "payload", b"payload", "range", b"range", "scope", b"scope"]) -> None: ...

global___SearchRequest = SearchRequest

@typing.final
class AdvancedSearchRequest(google.protobuf.message.Message):
    """AdvancedSearchRequest describes a search request with more filtering possibilities than SearchRequest. It returns
    formatted details about the twins matched by the supplied filter.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """Search request payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESPONSETYPE_FIELD_NUMBER: builtins.int
        FILTER_FIELD_NUMBER: builtins.int
        responseType: global___ResponseType.ValueType
        """Expected response type"""
        filter: builtins.str
        """The search filter, expressed as a JSON-encoded AST (in JSONLogic style)"""
        def __init__(
            self,
            *,
            responseType: global___ResponseType.ValueType = ...,
            filter: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["filter", b"filter", "responseType", b"responseType"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    RANGE_FIELD_NUMBER: builtins.int
    scope: iotics.api.common_pb2.Scope.ValueType
    """Search request scope"""
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """Search request headers"""

    @property
    def payload(self) -> global___AdvancedSearchRequest.Payload:
        """Search request payload"""

    @property
    def range(self) -> iotics.api.common_pb2.Range:
        """Search request range"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        scope: iotics.api.common_pb2.Scope.ValueType = ...,
        payload: global___AdvancedSearchRequest.Payload | None = ...,
        range: iotics.api.common_pb2.Range | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload", "range", b"range"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload", "range", b"range", "scope", b"scope"]) -> None: ...

global___AdvancedSearchRequest = AdvancedSearchRequest

@typing.final
class SearchResponse(google.protobuf.message.Message):
    """---------------------------------------------------------------------------------------------------------------------

    SearchResponse describes a result associated to a search request.
    It contains all the matching twins/feeds/inputs according to the request scope/range/lang/filters in the expected response type format.
    In the decentralised iotics operating environment, each node in the network generates a response and the client is expected to
    receive a stream of response messages.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FeedDetails(google.protobuf.message.Message):
        """Search response feed details. Included with response type: FULL."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FEEDID_FIELD_NUMBER: builtins.int
        STORELAST_FIELD_NUMBER: builtins.int
        PROPERTIES_FIELD_NUMBER: builtins.int
        storeLast: builtins.bool
        """whether offers the ability to store last received value"""
        @property
        def feedId(self) -> iotics.api.feed_pb2.FeedID:
            """Feed"""

        @property
        def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]:
            """Feed custom properties."""

        def __init__(
            self,
            *,
            feedId: iotics.api.feed_pb2.FeedID | None = ...,
            storeLast: builtins.bool = ...,
            properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["feedId", b"feedId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feedId", b"feedId", "properties", b"properties", "storeLast", b"storeLast"]) -> None: ...

    @typing.final
    class InputDetails(google.protobuf.message.Message):
        """Search response input details. Included with response type: FULL."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INPUTID_FIELD_NUMBER: builtins.int
        PROPERTIES_FIELD_NUMBER: builtins.int
        @property
        def inputId(self) -> iotics.api.input_pb2.InputID:
            """Input"""

        @property
        def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]:
            """Input custom properties."""

        def __init__(
            self,
            *,
            inputId: iotics.api.input_pb2.InputID | None = ...,
            properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["inputId", b"inputId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["inputId", b"inputId", "properties", b"properties"]) -> None: ...

    @typing.final
    class TwinDetails(google.protobuf.message.Message):
        """Search response twin details."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        LOCATION_FIELD_NUMBER: builtins.int
        PROPERTIES_FIELD_NUMBER: builtins.int
        FEEDS_FIELD_NUMBER: builtins.int
        INPUTS_FIELD_NUMBER: builtins.int
        UPDATEDAT_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Twin identifier. Included with response type: FULL, LOCATED and MINIMAL"""

        @property
        def location(self) -> iotics.api.common_pb2.GeoLocation:
            """Twin location (if set). Included with response type: FULL and LOCATED"""

        @property
        def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]:
            """Twin custom properties."""

        @property
        def feeds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SearchResponse.FeedDetails]:
            """Feed details. Included with response type: FULL"""

        @property
        def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SearchResponse.InputDetails]:
            """Input details. Included with response type: FULL"""

        @property
        def updatedAt(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """Twin updatedAt timestamp."""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
            location: iotics.api.common_pb2.GeoLocation | None = ...,
            properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
            feeds: collections.abc.Iterable[global___SearchResponse.FeedDetails] | None = ...,
            inputs: collections.abc.Iterable[global___SearchResponse.InputDetails] | None = ...,
            updatedAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["location", b"location", "twinId", b"twinId", "updatedAt", b"updatedAt"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feeds", b"feeds", "inputs", b"inputs", "location", b"location", "properties", b"properties", "twinId", b"twinId", "updatedAt", b"updatedAt"]) -> None: ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        """Search Response Payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESPONSETYPE_FIELD_NUMBER: builtins.int
        STATUS_FIELD_NUMBER: builtins.int
        HOSTID_FIELD_NUMBER: builtins.int
        TWINS_FIELD_NUMBER: builtins.int
        responseType: global___ResponseType.ValueType
        """Type of the response."""
        hostId: builtins.str
        """Host identifier string representation"""
        @property
        def status(self) -> google.rpc.status_pb2.Status:
            """Response status - if present indicates that this response is invalid"""

        @property
        def twins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SearchResponse.TwinDetails]:
            """Matching twins"""

        def __init__(
            self,
            *,
            responseType: global___ResponseType.ValueType = ...,
            status: google.rpc.status_pb2.Status | None = ...,
            hostId: builtins.str = ...,
            twins: collections.abc.Iterable[global___SearchResponse.TwinDetails] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["status", b"status"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["hostId", b"hostId", "responseType", b"responseType", "status", b"status", "twins", b"twins"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def payload(self) -> global___SearchResponse.Payload:
        """Search response payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___SearchResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___SearchResponse = SearchResponse

@typing.final
class DispatchSearchResponse(google.protobuf.message.Message):
    """---------------------------------------------------------------------------------------------------------------------

    Dispatch Search Response message.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DispatchSearchResponse = DispatchSearchResponse



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from iotics.api import twin_pb2 as iotics_dot_api_dot_twin__pb2


class TwinAPIStub(object):
    """---------------------------------------------------------------------------------------------------------------------

    TwinAPI enables creation and management of Iotics twins.
    Services only affect local resources, unless stated otherwise.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateTwin = channel.unary_unary(
                '/iotics.api.TwinAPI/CreateTwin',
                request_serializer=iotics_dot_api_dot_twin__pb2.CreateTwinRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_twin__pb2.CreateTwinResponse.FromString,
                _registered_method=True)
        self.UpsertTwin = channel.unary_unary(
                '/iotics.api.TwinAPI/UpsertTwin',
                request_serializer=iotics_dot_api_dot_twin__pb2.UpsertTwinRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_twin__pb2.UpsertTwinResponse.FromString,
                _registered_method=True)
        self.DeleteTwin = channel.unary_unary(
                '/iotics.api.TwinAPI/DeleteTwin',
                request_serializer=iotics_dot_api_dot_twin__pb2.DeleteTwinRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_twin__pb2.DeleteTwinResponse.FromString,
                _registered_method=True)
        self.UpdateTwin = channel.unary_unary(
                '/iotics.api.TwinAPI/UpdateTwin',
                request_serializer=iotics_dot_api_dot_twin__pb2.UpdateTwinRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_twin__pb2.UpdateTwinResponse.FromString,
                _registered_method=True)
        self.DescribeTwin = channel.unary_unary(
                '/iotics.api.TwinAPI/DescribeTwin',
                request_serializer=iotics_dot_api_dot_twin__pb2.DescribeTwinRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_twin__pb2.DescribeTwinResponse.FromString,
                _registered_method=True)
        self.ListAllTwins = channel.unary_unary(
                '/iotics.api.TwinAPI/ListAllTwins',
                request_serializer=iotics_dot_api_dot_twin__pb2.ListAllTwinsRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_twin__pb2.ListAllTwinsResponse.FromString,
                _registered_method=True)


class TwinAPIServicer(object):
    """---------------------------------------------------------------------------------------------------------------------

    TwinAPI enables creation and management of Iotics twins.
    Services only affect local resources, unless stated otherwise.
    """

    def CreateTwin(self, request, context):
        """CreateTwin creates a twin.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertTwin(self, request, context):
        """UpsertTwin creates or updates a twin with its metadata + the twin feeds and inputs with their metadata.
        The full state is applied (ie. if the operation succeeds the state of the twin, feeds and inputs will be the one
        described in the payload)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTwin(self, request, context):
        """DeleteTwin deletes a twin.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTwin(self, request, context):
        """UpdateTwin updates a twin (partial update).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DescribeTwin(self, request, context):
        """Describes a twin. (local and remote)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAllTwins(self, request, context):
        """List all twins.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TwinAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateTwin': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTwin,
                    request_deserializer=iotics_dot_api_dot_twin__pb2.CreateTwinRequest.FromString,
                    response_serializer=iotics_dot_api_dot_twin__pb2.CreateTwinResponse.SerializeToString,
            ),
            'UpsertTwin': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertTwin,
                    request_deserializer=iotics_dot_api_dot_twin__pb2.UpsertTwinRequest.FromString,
                    response_serializer=iotics_dot_api_dot_twin__pb2.UpsertTwinResponse.SerializeToString,
            ),
            'DeleteTwin': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTwin,
                    request_deserializer=iotics_dot_api_dot_twin__pb2.DeleteTwinRequest.FromString,
                    response_serializer=iotics_dot_api_dot_twin__pb2.DeleteTwinResponse.SerializeToString,
            ),
            'UpdateTwin': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTwin,
                    request_deserializer=iotics_dot_api_dot_twin__pb2.UpdateTwinRequest.FromString,
                    response_serializer=iotics_dot_api_dot_twin__pb2.UpdateTwinResponse.SerializeToString,
            ),
            'DescribeTwin': grpc.unary_unary_rpc_method_handler(
                    servicer.DescribeTwin,
                    request_deserializer=iotics_dot_api_dot_twin__pb2.DescribeTwinRequest.FromString,
                    response_serializer=iotics_dot_api_dot_twin__pb2.DescribeTwinResponse.SerializeToString,
            ),
            'ListAllTwins': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAllTwins,
                    request_deserializer=iotics_dot_api_dot_twin__pb2.ListAllTwinsRequest.FromString,
                    response_serializer=iotics_dot_api_dot_twin__pb2.ListAllTwinsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'iotics.api.TwinAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('iotics.api.TwinAPI', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TwinAPI(object):
    """---------------------------------------------------------------------------------------------------------------------

    TwinAPI enables creation and management of Iotics twins.
    Services only affect local resources, unless stated otherwise.
    """

    @staticmethod
    def CreateTwin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.TwinAPI/CreateTwin',
            iotics_dot_api_dot_twin__pb2.CreateTwinRequest.SerializeToString,
            iotics_dot_api_dot_twin__pb2.CreateTwinResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpsertTwin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.TwinAPI/UpsertTwin',
            iotics_dot_api_dot_twin__pb2.UpsertTwinRequest.SerializeToString,
            iotics_dot_api_dot_twin__pb2.UpsertTwinResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteTwin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.TwinAPI/DeleteTwin',
            iotics_dot_api_dot_twin__pb2.DeleteTwinRequest.SerializeToString,
            iotics_dot_api_dot_twin__pb2.DeleteTwinResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateTwin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.TwinAPI/UpdateTwin',
            iotics_dot_api_dot_twin__pb2.UpdateTwinRequest.SerializeToString,
            iotics_dot_api_dot_twin__pb2.UpdateTwinResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DescribeTwin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.TwinAPI/DescribeTwin',
            iotics_dot_api_dot_twin__pb2.DescribeTwinRequest.SerializeToString,
            iotics_dot_api_dot_twin__pb2.DescribeTwinResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAllTwins(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.TwinAPI/ListAllTwins',
            iotics_dot_api_dot_twin__pb2.ListAllTwinsRequest.SerializeToString,
            iotics_dot_api_dot_twin__pb2.ListAllTwinsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/common.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17iotics/api/common.proto\x12\niotics.api\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1d\n\x05Limit\x12\x14\n\x05value\x18\x01 \x01(\rR\x05value\"\x1e\n\x06Offset\x12\x14\n\x05value\x18\x01 \x01(\rR\x05value\"\\\n\x05Range\x12\'\n\x05limit\x18\x01 \x01(\x0b\x32\x11.iotics.api.LimitR\x05limit\x12*\n\x06offset\x18\x02 \x01(\x0b\x32\x12.iotics.api.OffsetR\x06offset\"7\n\x0bLangLiteral\x12\x12\n\x04lang\x18\x01 \x01(\tR\x04lang\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"%\n\rStringLiteral\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\";\n\x07Literal\x12\x1a\n\x08\x64\x61taType\x18\x01 \x01(\tR\x08\x64\x61taType\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"\x1b\n\x03Uri\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\"\xa3\x02\n\x08Property\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x39\n\x0cliteralValue\x18\x02 \x01(\x0b\x32\x13.iotics.api.LiteralH\x00R\x0cliteralValue\x12\x45\n\x10langLiteralValue\x18\x03 \x01(\x0b\x32\x17.iotics.api.LangLiteralH\x00R\x10langLiteralValue\x12K\n\x12stringLiteralValue\x18\x04 \x01(\x0b\x32\x19.iotics.api.StringLiteralH\x00R\x12stringLiteralValue\x12-\n\x08uriValue\x18\x05 \x01(\x0b\x32\x0f.iotics.api.UriH\x00R\x08uriValueB\x07\n\x05value\"1\n\x0bGeoLocation\x12\x10\n\x03lat\x18\x01 \x01(\x01R\x03lat\x12\x10\n\x03lon\x18\x02 \x01(\x01R\x03lon\"\\\n\tGeoCircle\x12\x33\n\x08location\x18\x01 \x01(\x0b\x32\x17.iotics.api.GeoLocationR\x08location\x12\x1a\n\x08radiusKm\x18\x02 \x01(\x01R\x08radiusKm\"\xc7\x01\n\x0bRequestInfo\x12\x38\n\tstartTime\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x41\n\x08traceCtx\x18\x02 \x03(\x0b\x32%.iotics.api.RequestInfo.TraceCtxEntryR\x08traceCtx\x1a;\n\rTraceCtxEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xb4\x02\n\x07Headers\x12\x1c\n\tclientRef\x18\x01 \x01(\tR\tclientRef\x12 \n\x0b\x63lientAppId\x18\x02 \x01(\tR\x0b\x63lientAppId\x12&\n\x0etransactionRef\x18\x03 \x03(\tR\x0etransactionRef\x12\x42\n\rconsumerGroup\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rconsumerGroup\x12\x42\n\x0erequestTimeout\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0erequestTimeout\x12\x39\n\x0brequestInfo\x18\x06 \x01(\x0b\x32\x17.iotics.api.RequestInfoR\x0brequestInfo\"\xa3\x01\n\x13SubscriptionHeaders\x12 \n\x0b\x63lientAppId\x18\x01 \x01(\tR\x0b\x63lientAppId\x12&\n\x0etransactionRef\x18\x02 \x03(\tR\x0etransactionRef\x12\x42\n\rconsumerGroup\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rconsumerGroup\"0\n\x06TwinID\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06hostId\x18\x02 \x01(\tR\x06hostId\"g\n\x05Value\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x12\x18\n\x07\x63omment\x18\x02 \x01(\tR\x07\x63omment\x12\x12\n\x04unit\x18\x03 \x01(\tR\x04unit\x12\x1a\n\x08\x64\x61taType\x18\x04 \x01(\tR\x08\x64\x61taType\"Y\n\x06Values\x12\'\n\x05\x61\x64\x64\x65\x64\x18\x01 \x03(\x0b\x32\x11.iotics.api.ValueR\x05\x61\x64\x64\x65\x64\x12&\n\x0e\x64\x65letedByLabel\x18\x02 \x03(\tR\x0e\x64\x65letedByLabel\"n\n\x08\x46\x65\x65\x64\x44\x61ta\x12:\n\noccurredAt\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12\x12\n\x04mime\x18\x03 \x01(\tR\x04mime\x12\x12\n\x04\x64\x61ta\x18\x04 \x01(\x0cR\x04\x64\x61ta\"\xb0\x01\n\x0ePropertyUpdate\x12\x1e\n\nclearedAll\x18\x01 \x01(\x08R\nclearedAll\x12.\n\x07\x64\x65leted\x18\x02 \x03(\x0b\x32\x14.iotics.api.PropertyR\x07\x64\x65leted\x12\"\n\x0c\x64\x65letedByKey\x18\x03 \x03(\tR\x0c\x64\x65letedByKey\x12*\n\x05\x61\x64\x64\x65\x64\x18\x04 \x03(\x0b\x32\x14.iotics.api.PropertyR\x05\x61\x64\x64\x65\x64*\x1e\n\x05Scope\x12\n\n\x06GLOBAL\x10\x00\x12\t\n\x05LOCAL\x10\x01\x42\x7f\n\x0e\x63om.iotics.apiB\x0b\x43ommonProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\013CommonProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_REQUESTINFO_TRACECTXENTRY']._loaded_options = None
  _globals['_REQUESTINFO_TRACECTXENTRY']._serialized_options = b'8\001'
  _globals['_SCOPE']._serialized_start=2102
  _globals['_SCOPE']._serialized_end=2132
  _globals['_LIMIT']._serialized_start=104
  _globals['_LIMIT']._serialized_end=133
  _globals['_OFFSET']._serialized_start=135
  _globals['_OFFSET']._serialized_end=165
  _globals['_RANGE']._serialized_start=167
  _globals['_RANGE']._serialized_end=259
  _globals['_LANGLITERAL']._serialized_start=261
  _globals['_LANGLITERAL']._serialized_end=316
  _globals['_STRINGLITERAL']._serialized_start=318
  _globals['_STRINGLITERAL']._serialized_end=355
  _globals['_LITERAL']._serialized_start=357
  _globals['_LITERAL']._serialized_end=416
  _globals['_URI']._serialized_start=418
  _globals['_URI']._serialized_end=445
  _globals['_PROPERTY']._serialized_start=448
  _globals['_PROPERTY']._serialized_end=739
  _globals['_GEOLOCATION']._serialized_start=741
  _globals['_GEOLOCATION']._serialized_end=790
  _globals['_GEOCIRCLE']._serialized_start=792
  _globals['_GEOCIRCLE']._serialized_end=884
  _globals['_REQUESTINFO']._serialized_start=887
  _globals['_REQUESTINFO']._serialized_end=1086
  _globals['_REQUESTINFO_TRACECTXENTRY']._serialized_start=1027
  _globals['_REQUESTINFO_TRACECTXENTRY']._serialized_end=1086
  _globals['_HEADERS']._serialized_start=1089
  _globals['_HEADERS']._serialized_end=1397
  _globals['_SUBSCRIPTIONHEADERS']._serialized_start=1400
  _globals['_SUBSCRIPTIONHEADERS']._serialized_end=1563
  _globals['_TWINID']._serialized_start=1565
  _globals['_TWINID']._serialized_end=1613
  _globals['_VALUE']._serialized_start=1615
  _globals['_VALUE']._serialized_end=1718
  _globals['_VALUES']._serialized_start=1720
  _globals['_VALUES']._serialized_end=1809
  _globals['_FEEDDATA']._serialized_start=1811
  _globals['_FEEDDATA']._serialized_end=1921
  _globals['_PROPERTYUPDATE']._serialized_start=1924
  _globals['_PROPERTYUPDATE']._serialized_end=2100
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (feed)
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import iotics.api.common_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class FeedID(google.protobuf.message.Message):
    """A feed representation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TWINID_FIELD_NUMBER: builtins.int
    HOSTID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Feed identifier string representation (simple string) (unique within the scope of a twin identifier's feed set)"""
    twinId: builtins.str
    """Twin identifier string representation (simple string) (twin to which the feed belongs)"""
    hostId: builtins.str
    """Host identifier string representation (simple string) (Host to which the twin belongs)"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        twinId: builtins.str = ...,
        hostId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hostId", b"hostId", "id", b"id", "twinId", b"twinId"]) -> None: ...

global___FeedID = FeedID

@typing.final
class CreateFeedRequest(google.protobuf.message.Message):
    """CreateFeedRequestCreate is used to create a new feed in a given twin."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """Payload describes the data needed to create a feed."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        id: builtins.str
        """Feed identifier string representation (simple string) (unique within the scope of a twin identifier's feed set)"""
        def __init__(
            self,
            *,
            id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """Arguments describes the mandatory arguments to identify the twin the feed belongs to."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Identifier of the twin owning this feed"""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["twinId", b"twinId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["twinId", b"twinId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """CreateFeedRequest headers"""

    @property
    def args(self) -> global___CreateFeedRequest.Arguments:
        """CreateFeedRequest mandatory arguments"""

    @property
    def payload(self) -> global___CreateFeedRequest.Payload:
        """CreateFeedRequest payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___CreateFeedRequest.Arguments | None = ...,
        payload: global___CreateFeedRequest.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "payload", b"payload"]) -> None: ...

global___CreateFeedRequest = CreateFeedRequest

@typing.final
class CreateFeedResponse(google.protobuf.message.Message):
    """CreateFeedResponse describes a created feed."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """CreateFeedResponse payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FEEDID_FIELD_NUMBER: builtins.int
        @property
        def feedId(self) -> global___FeedID:
            """The created feed"""

        def __init__(
            self,
            *,
            feedId: global___FeedID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["feedId", b"feedId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feedId", b"feedId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """CreateFeedResponse headers"""

    @property
    def payload(self) -> global___CreateFeedResponse.Payload:
        """CreateFeedResponse payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___CreateFeedResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___CreateFeedResponse = CreateFeedResponse

@typing.final
class DeleteFeedRequest(google.protobuf.message.Message):
    """DeleteFeedRequest is used to delete a feed from a given twin."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """DeleteFeedRequest arguments."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FEEDID_FIELD_NUMBER: builtins.int
        @property
        def feedId(self) -> global___FeedID:
            """Feed to delete"""

        def __init__(
            self,
            *,
            feedId: global___FeedID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["feedId", b"feedId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feedId", b"feedId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """DeleteFeedRequest headers"""

    @property
    def args(self) -> global___DeleteFeedRequest.Arguments:
        """DeleteFeedRequest mandatory arguments"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___DeleteFeedRequest.Arguments | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> None: ...

global___DeleteFeedRequest = DeleteFeedRequest

@typing.final
class DeleteFeedResponse(google.protobuf.message.Message):
    """DeleteFeedResponse describes a deleted feed."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """DeleteFeedResponse payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FEEDID_FIELD_NUMBER: builtins.int
        @property
        def feedId(self) -> global___FeedID:
            """Deleted feed"""

        def __init__(
            self,
            *,
            feedId: global___FeedID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["feedId", b"feedId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feedId", b"feedId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """DeleteFeedResponse headers"""

    @property
    def payload(self) -> global___DeleteFeedResponse.Payload:
        """DeleteFeedResponse payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___DeleteFeedResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___DeleteFeedResponse = DeleteFeedResponse

@typing.final
class UpdateFeedRequest(google.protobuf.message.Message):
    """UpdateFeedRequest is used to update attributes (including metadata) of a given feed."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """UpdateFeedRequest payload. One or more fields can be provided, depending on what needs to be updated.
        Note that the specified metadata changes are applied in the following order:
        tags, values, labels, comments
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STORELAST_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        PROPERTIES_FIELD_NUMBER: builtins.int
        @property
        def storeLast(self) -> google.protobuf.wrappers_pb2.BoolValue:
            """StoreLast dictates whether to store the last shared sample of a feed."""

        @property
        def values(self) -> iotics.api.common_pb2.Values:
            """Values are descriptive individual data items to add/remove."""

        @property
        def properties(self) -> iotics.api.common_pb2.PropertyUpdate:
            """Custom properties to add/remove. Internal properties (such as location) cannot be modified here."""

        def __init__(
            self,
            *,
            storeLast: google.protobuf.wrappers_pb2.BoolValue | None = ...,
            values: iotics.api.common_pb2.Values | None = ...,
            properties: iotics.api.common_pb2.PropertyUpdate | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["properties", b"properties", "storeLast", b"storeLast", "values", b"values"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["properties", b"properties", "storeLast", b"storeLast", "values", b"values"]) -> None: ...

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """UpdateFeedRequest arguments."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FEEDID_FIELD_NUMBER: builtins.int
        @property
        def feedId(self) -> global___FeedID: ...
        def __init__(
            self,
            *,
            feedId: global___FeedID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["feedId", b"feedId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feedId", b"feedId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """UpdateFeedRequest headers"""

    @property
    def args(self) -> global___UpdateFeedRequest.Arguments:
        """UpdateFeedRequest arguments"""

    @property
    def payload(self) -> global___UpdateFeedRequest.Payload:
        """UpdateFeedRequest payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___UpdateFeedRequest.Arguments | None = ...,
        payload: global___UpdateFeedRequest.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "payload", b"payload"]) -> None: ...

global___UpdateFeedRequest = UpdateFeedRequest

@typing.final
class UpdateFeedResponse(google.protobuf.message.Message):
    """UpdateFeedResponse is used to indicate a successful update."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """UpdateFeedResponse payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FEEDID_FIELD_NUMBER: builtins.int
        @property
        def feedId(self) -> global___FeedID:
            """Updated feed"""

        def __init__(
            self,
            *,
            feedId: global___FeedID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["feedId", b"feedId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feedId", b"feedId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """UpdateFeedResponse headers"""

    @property
    def payload(self) -> global___UpdateFeedResponse.Payload:
        """UpdateFeedResponse payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___UpdateFeedResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___UpdateFeedResponse = UpdateFeedResponse

@typing.final
class ShareFeedDataRequest(google.protobuf.message.Message):
    """ShareFeedDataRequest is used to share a new sample of data for the given feed."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """ShareFeedDataRequest payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SAMPLE_FIELD_NUMBER: builtins.int
        @property
        def sample(self) -> iotics.api.common_pb2.FeedData:
            """Sample to share"""

        def __init__(
            self,
            *,
            sample: iotics.api.common_pb2.FeedData | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["sample", b"sample"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["sample", b"sample"]) -> None: ...

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """ShareFeedDataRequest arguments."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FEEDID_FIELD_NUMBER: builtins.int
        @property
        def feedId(self) -> global___FeedID:
            """Feed sharing the sample"""

        def __init__(
            self,
            *,
            feedId: global___FeedID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["feedId", b"feedId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feedId", b"feedId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """ShareFeedDataRequest headers"""

    @property
    def args(self) -> global___ShareFeedDataRequest.Arguments:
        """ShareFeedDataRequest arguments"""

    @property
    def payload(self) -> global___ShareFeedDataRequest.Payload:
        """ShareFeedDataRequest payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___ShareFeedDataRequest.Arguments | None = ...,
        payload: global___ShareFeedDataRequest.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "payload", b"payload"]) -> None: ...

global___ShareFeedDataRequest = ShareFeedDataRequest

@typing.final
class ShareFeedDataResponse(google.protobuf.message.Message):
    """ShareFeedDataResponse is used to indicate a successful feed share."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADERS_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """ShareFeedDataResponse headers"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers"]) -> None: ...

global___ShareFeedDataResponse = ShareFeedDataResponse

@typing.final
class ListAllFeedsRequest(google.protobuf.message.Message):
    """ListAllFeedsRequest is used to list all the feeds owned by a given twin."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """ListAllFeedsRequest mandatory arguments."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TWINID_FIELD_NUMBER: builtins.int
        @property
        def twinId(self) -> iotics.api.common_pb2.TwinID:
            """Identifier of the twin owning this feed"""

        def __init__(
            self,
            *,
            twinId: iotics.api.common_pb2.TwinID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["twinId", b"twinId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["twinId", b"twinId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    RANGE_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """ListAllFeedsRequest headers"""

    @property
    def args(self) -> global___ListAllFeedsRequest.Arguments:
        """ListAllFeedsRequest arguments"""

    @property
    def range(self) -> iotics.api.common_pb2.Range:
        """Limit the results according to the value
        (optional: when not supplied, assume no default limits required - See https://ioticlabs.atlassian.net/browse/FO-1362)
        """

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___ListAllFeedsRequest.Arguments | None = ...,
        range: iotics.api.common_pb2.Range | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "range", b"range"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "range", b"range"]) -> None: ...

global___ListAllFeedsRequest = ListAllFeedsRequest

@typing.final
class ListAllFeedsResponse(google.protobuf.message.Message):
    """ListAllFeedsResponse describes the list of the feeds owned by a twin."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """ListAllFeedsResponse payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FEEDIDS_FIELD_NUMBER: builtins.int
        @property
        def feedIds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeedID]:
            """List of the feeds owned by the twin"""

        def __init__(
            self,
            *,
            feedIds: collections.abc.Iterable[global___FeedID] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["feedIds", b"feedIds"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """ListAllFeedsResponse headers"""

    @property
    def payload(self) -> global___ListAllFeedsResponse.Payload:
        """ListAllFeedsResponse payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___ListAllFeedsResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___ListAllFeedsResponse = ListAllFeedsResponse

@typing.final
class DescribeFeedRequest(google.protobuf.message.Message):
    """Description of twin: Provides public metadata lookup for individual resources."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """DescribeFeedRequest arguments."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FEEDID_FIELD_NUMBER: builtins.int
        @property
        def feedId(self) -> global___FeedID:
            """Feed to describe"""

        def __init__(
            self,
            *,
            feedId: global___FeedID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["feedId", b"feedId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feedId", b"feedId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """DescribeFeedRequest headers"""

    @property
    def args(self) -> global___DescribeFeedRequest.Arguments:
        """DescribeFeedRequest mandatory arguments"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___DescribeFeedRequest.Arguments | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> None: ...

global___DescribeFeedRequest = DescribeFeedRequest

@typing.final
class DescribeFeedResponse(google.protobuf.message.Message):
    """Describe feed response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class MetaResult(google.protobuf.message.Message):
        """Metadata result databag."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VALUES_FIELD_NUMBER: builtins.int
        STORELAST_FIELD_NUMBER: builtins.int
        PROPERTIES_FIELD_NUMBER: builtins.int
        storeLast: builtins.bool
        """Whether this feed might have its most recent data sample stored. If so, it can be retrieved via FetchLastStored
        request. (See interest API)
        """
        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Value]:
            """Values semantically describing the share payload of Feed"""

        @property
        def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]:
            """Custom properties associated with this feed."""

        def __init__(
            self,
            *,
            values: collections.abc.Iterable[iotics.api.common_pb2.Value] | None = ...,
            storeLast: builtins.bool = ...,
            properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["properties", b"properties", "storeLast", b"storeLast", "values", b"values"]) -> None: ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        """DescribeFeedResponse payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FEEDID_FIELD_NUMBER: builtins.int
        RESULT_FIELD_NUMBER: builtins.int
        @property
        def feedId(self) -> global___FeedID:
            """Described feed"""

        @property
        def result(self) -> global___DescribeFeedResponse.MetaResult:
            """Metadata result"""

        def __init__(
            self,
            *,
            feedId: global___FeedID | None = ...,
            result: global___DescribeFeedResponse.MetaResult | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["feedId", b"feedId", "result", b"result"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feedId", b"feedId", "result", b"result"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """DescribeFeedResponse headers"""

    @property
    def payload(self) -> global___DescribeFeedResponse.Payload:
        """DescribeFeedResponse payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___DescribeFeedResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___DescribeFeedResponse = DescribeFeedResponse

@typing.final
class UpsertFeedWithMeta(google.protobuf.message.Message):
    """UpsertFeedWithMeta is used to describe the full feed state. Used in UpsertTwinRequest."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    STORELAST_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Feed identifier string representation (simple string) (unique within the scope of a twin identifier's feed set)"""
    storeLast: builtins.bool
    """StoreLast dictates whether to store the last shared sample of the feed. Default 'False'"""
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Value]:
        """Values to set"""

    @property
    def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]:
        """Feed properties to set"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        storeLast: builtins.bool = ...,
        values: collections.abc.Iterable[iotics.api.common_pb2.Value] | None = ...,
        properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "properties", b"properties", "storeLast", b"storeLast", "values", b"values"]) -> None: ...

global___UpsertFeedWithMeta = UpsertFeedWithMeta
